---
title: Roadmap 2021
---

This post is in response to an e-mail I've received. I'm trying to outline
the near-term roadmap for 2021.

# Ideas and Visions

> On the one hand it seems to be mature and complete. On the other hand there
> also show up a lot of potential things to improve.

The vision for what I want to achieve is best summarized in the [workflow]({{
site.baseurl }}{% link workflow.md %}) document. It won't be about
requirements tracking solely, but also about software life-cycle.

I think there are a couple of things needed to make it feature-complete.
Probably not a conclusive list, and partially already covered here:
<https://github.com/kown7/rmtoo/projects/1>.

* Multi-Document Traceability
* More traceability inputs in general
    * Currently merely pytest xunit
* Possibly markdown requirements instead of latex
    * this opens up a whole list of new options
    * convert documents using pandoc
	
# Presentation

This is in the same [vein](../../../assets/rmtoo-Traceability.pdf)

# Fork's Origin

The fork happend more by accident as I was toying with flit and didn't want
the install from a github repository anymore. The end-goal is to merge it back,
but that might just be too big a task.
